<!--
 Copyright 2025 Lordseriouspig
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
     https://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->
# Py24

[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Overview

**Py24** is a simple python module to interface with Pi24 installations.

## Installation

```bash
pip install Py24
```

## Usage

```python
import pi24_monitor as pi24

info = pi24.get_monitor(HOST,IP,FILTER) # Returns a JSON object of your radar's status
aircraft = pi24.get_aircraft(HOST,IP) # Returns a JSON object of the planes in your radar's range
```

## Requirements

- Python 3.7+
- A device running Pi24 on your network

## License

This project is licensed under the Apache License 2.0. See the [LICENSE](https://www.apache.org/licenses/LICENSE-2.0) file for details.
